summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/request_shapifier.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/query/request_shapifier.h')
-rw-r--r--src/mongo/db/query/request_shapifier.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/mongo/db/query/request_shapifier.h b/src/mongo/db/query/request_shapifier.h
index 1bae8f913f9..37004197fd0 100644
--- a/src/mongo/db/query/request_shapifier.h
+++ b/src/mongo/db/query/request_shapifier.h
@@ -34,27 +34,27 @@
#include "mongo/db/query/serialization_options.h"
#include "mongo/rpc/metadata/client_metadata.h"
-namespace mongo::telemetry {
+namespace mongo::query_stats {
/**
* An abstract base class to handle query shapification for telemetry. Each request type should
* define its own shapification strategy in its implementation of makeTelemetryKey(), and then a
* request should be registered with telemetry via telemetry::registerRequest(RequestShapifier).
*/
class RequestShapifier {
public:
virtual ~RequestShapifier() = default;
/**
* makeTelemetryKey generates the telemetry key representative of the specific request's
* payload. If there exists an ExpressionContext set up to parse and evaluate the request,
* makeTelemetryKey should be called with that ExpressionContext. If not, you can call the
* overload that accepts the OperationContext and will construct a minimally-acceptable
* ExpressionContext for the sake of generating the key.
*/
- virtual BSONObj makeTelemetryKey(const SerializationOptions& opts,
- OperationContext* opCtx) const = 0;
- virtual BSONObj makeTelemetryKey(
+ virtual BSONObj makeQueryStatsKey(const SerializationOptions& opts,
+ OperationContext* opCtx) const = 0;
+ virtual BSONObj makeQueryStatsKey(
const SerializationOptions& opts,
const boost::intrusive_ptr<ExpressionContext>& expCtx) const = 0;
@@ -79,4 +79,4 @@ protected:
BSONObj _commentObj;
boost::optional<BSONElement> _comment = boost::none;
};
-} // namespace mongo::telemetry
+} // namespace mongo::query_stats
@@ -34,27 +34,27 @@
/**
- * An abstract base class to handle query shapification for telemetry. Each request type should
- * define its own shapification strategy in its implementation of makeTelemetryKey(), and then a
- * request should be registered with telemetry via telemetry::registerRequest(RequestShapifier).
+ * An abstract base class to handle query shapification for queryStats. Each request type should
+ * define its own shapification strategy in its implementation of makeQueryStatsKey(), and then a
+ * request should be registered with queryStats via query_stats::registerRequest(RequestShapifier).
*/
class RequestShapifier {
@@ -34,27 +34,27 @@
virtual ~RequestShapifier() = default;
/**
- * makeTelemetryKey generates the telemetry key representative of the specific request's
+ * makeQueryStatsKey generates the telemetry key representative of the specific request's
* payload. If there exists an ExpressionContext set up to parse and evaluate the request,
@@ -34,27 +34,27 @@
* payload. If there exists an ExpressionContext set up to parse and evaluate the request,
- * makeTelemetryKey should be called with that ExpressionContext. If not, you can call the
+ * makeQueryStatsKey should be called with that ExpressionContext. If not, you can call the
* overload that accepts the OperationContext and will construct a minimally-acceptable
* ExpressionContext for the sake of generating the key.